@@ -18,28 +18,30 @@
  *                                                                         *
  ***************************************************************************/
 #include "FractionRingWidget.h"
-#include "FractionRingWidget.moc"
 
 /* these includes are needed for KDE support */
-#include <KAction>
-#include <kactioncollection.h>
-#include <kconfigdialog.h>
-#include <klocale.h>
-#include <KNumInput>
-#include <kstandardaction.h>
+#include <KActionCollection>
+#include <KConfigDialog>
+#include <KLocalizedString>
+#include <KStandardAction>
 #include <KStandardShortcut>
-#include <KTextEdit>
 
 /* these includes are needed for Qt support */
-#include <qapplication.h>
-
-//Added by qt3to4:
+#include <QAction>
+#include <QApplication>
 #include <QGridLayout>
 #include <QLabel>
 #include <QPainter>
-#include <QRectF>
-#include <QString>
 #include <QPushButton>
+#include <QRectF>
+#include <QSpinBox>
+#include <QString>
+#include <QTextEdit>
+#include <QWidgetAction>
+
+#ifdef DEBUG
+#include <QDebug>
+#endif
 
 #include "Ratio.h"
 #include "FractionPainter.h"
@@ -54,28 +56,28 @@
 FractionRingWidget::FractionRingWidget()
 {
 #ifdef DEBUG
-    kDebug() << "constructor FractionRingWidget()";
+    qDebug() << QStringLiteral("constructor FractionRingWidget()");
 #endif
     // creating KActions, used by the FractionRingWidgetui.rc file
     setupActions();
-    createGUI("FractionRingWidgetui.rc");
+    createGUI(QStringLiteral("FractionRingWidgetui.rc"));
 
     setCaption(i18n("Learning"));
 
     layout1 = new QGridLayout();
-    layout1->setObjectName("layout1");
+    layout1->setObjectName(QStringLiteral("layout1"));
 
     baseWidget = new QWidget();
-    baseWidget->setObjectName("baseWidget");
+    baseWidget->setObjectName(QStringLiteral("baseWidget"));
 
     setCentralWidget(baseWidget);
 
     interfaceWidget = new QWidget(this);
-    interfaceWidget->setObjectName("interfaceWidget");
+    interfaceWidget->setObjectName(QStringLiteral("interfaceWidget"));
     interfaceWidget->setFixedSize(QSize(270, 300));
 
     gridLayout = new QGridLayout();
-    gridLayout->setObjectName("gridLayout");
+    gridLayout->setObjectName(QStringLiteral("gridLayout"));
 
     // setup colors ---------------------------------------
     bgOutsideRing = QColor(242, 242, 242);
@@ -105,50 +107,47 @@ FractionRingWidget::FractionRingWidget()
     move(50, 50);
 
     fractionWidget = new FractionPainter(this);
-    fractionWidget->setObjectName("fractionWidget");
+    fractionWidget->setObjectName(QStringLiteral("fractionWidget"));
 
     gridLayout->addWidget(fractionWidget, 0, 0, 1, 2, Qt::AlignBottom | Qt::AlignHCenter);
 
     // Info Labels -------------------------------------
     leftInfoLabel = new QLabel(this);
-    leftInfoLabel->setObjectName("leftInfoLabel");
+    leftInfoLabel->setObjectName(QStringLiteral("leftInfoLabel"));
     leftInfoLabel->setText(i18nc("Expands the ratio shown on the left by the given factor. Please note, expanding is not the same as multiplying. For example, expanding a ratio by 2 basically means multiplying the ratio with 2/2 and not with 2/1!", "Expand"));
     gridLayout->addWidget(leftInfoLabel, 1, 0, Qt::AlignCenter);
 
     rightInfoLabel = new QLabel(this);
-    rightInfoLabel->setObjectName("rightInfoLabel");
+    rightInfoLabel->setObjectName(QStringLiteral("rightInfoLabel"));
     rightInfoLabel->setText(i18nc("Expands the ratio shown on the left by the given factor. Please note, expanding is not the same as multiplying. For example, expanding a ratio by 2 basically means multiplying the ratio with 2/2 and not with 2/1!", "Expand"));
     gridLayout->addWidget(rightInfoLabel, 1, 1, Qt::AlignCenter);
 
     // SpinBox -----------------------------------------
-    leftSpinBox = new KIntSpinBox(this);
-    leftSpinBox->setObjectName("leftSpinBox");
+    leftSpinBox = new QSpinBox(this);
+    leftSpinBox->setObjectName(QStringLiteral("leftSpinBox"));
     leftSpinBox->setRange(1, 6);
     leftSpinBox->setMaximumWidth(50);
     leftSpinBox->setMinimumWidth(50);
     gridLayout->addWidget(leftSpinBox, 2, 0, Qt::AlignTop | Qt::AlignHCenter);
 
-    rightSpinBox = new KIntSpinBox(this);
-    rightSpinBox->setObjectName("rightSpinBox");
+    rightSpinBox = new QSpinBox(this);
+    rightSpinBox->setObjectName(QStringLiteral("rightSpinBox"));
     rightSpinBox->setRange(1, 6);
     rightSpinBox->setMaximumWidth(50);
     rightSpinBox->setMinimumWidth(50);
     gridLayout->addWidget(rightSpinBox, 2, 1, Qt::AlignTop | Qt::AlignHCenter);
 
-    QObject::connect(leftSpinBox, SIGNAL(valueChanged(int)), this,
-                     SLOT(slotLeftSpinBoxValueChanged(int)));
-    QObject::connect(rightSpinBox, SIGNAL(valueChanged(int)), this,
-                     SLOT(slotRightSpinBoxValueChanged(int)));
+    QObject::connect(leftSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &FractionRingWidget::slotLeftSpinBoxValueChanged);
+    QObject::connect(rightSpinBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &FractionRingWidget::slotRightSpinBoxValueChanged);
 
     // Reset Button ------------------------------------
     resetButton = new QPushButton(this);
-    resetButton->setObjectName("resetButton");
+    resetButton->setObjectName(QStringLiteral("resetButton"));
     resetButton->setText(i18n("New"));
     resetButton->setMaximumWidth(70);
     gridLayout->addWidget(resetButton, 3, 0, 1, 2, Qt::AlignCenter);
 
-    QObject::connect(resetButton, SIGNAL(clicked()), this,
-                     SLOT(NewTask()));
+    QObject::connect(resetButton, &QPushButton::clicked, this, &FractionRingWidget::NewTask);
 
     // grid row settings --------------------------------
     gridLayout->setRowMinimumHeight(0, 185);
@@ -160,8 +159,8 @@ FractionRingWidget::FractionRingWidget()
     layout1->addWidget(interfaceWidget, 1, 0, Qt::AlignTop | Qt::AlignHCenter);
 
     // textedit -----------------------------------------
-    textMsg = new KTextEdit(this);
-    textMsg->setObjectName("textMsg");
+    textMsg = new QTextEdit(this);
+    textMsg->setObjectName(QStringLiteral("textMsg"));
     textMsg->setFixedSize(QSize(250 - MARG_LEFT, 300));
     textMsg->setReadOnly(true);
     textMsg->setPalette(QPalette(QColor(255, 255, 255)));
@@ -186,38 +185,42 @@ FractionRingWidget::FractionRingWidget()
 FractionRingWidget::~FractionRingWidget()
 {
 #ifdef DEBUG
-    kDebug() << "destructor StatisticsBarWidget()";
+    qDebug() << QStringLiteral("destructor StatisticsBarWidget()");
 #endif
 }
 
 void FractionRingWidget::setupActions()
 {
 #ifdef DEBUG
-    kDebug() << "setupActions FractionRingWidget";
+    qDebug() << QStringLiteral("setupActions FractionRingWidget");
 #endif
     // new task action
-    m_NewTaskAction  = new KAction(KIcon("document-new"), i18nc("@action opens a new question", "&New"), this);
-    actionCollection()->addAction("NewTask", m_NewTaskAction);
-    connect(m_NewTaskAction, SIGNAL(triggered(bool)), SLOT(NewTask()));
-    m_NewTaskAction->setShortcut(KStandardShortcut::shortcut(KStandardShortcut::New));
+    m_NewTaskAction = new QWidgetAction(this);
+    m_NewTaskAction->setText(i18nc("@action opens a new question", "&New"));
+    m_NewTaskAction->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
+    actionCollection()->addAction(QStringLiteral("NewTask"), m_NewTaskAction);
+    actionCollection()->setDefaultShortcuts(m_NewTaskAction, KStandardShortcut::shortcut(KStandardShortcut::New));
+    connect(m_NewTaskAction, &QAction::triggered, this, &FractionRingWidget::NewTask);
 
     // back action
-    m_BackAction  = new KAction(KIcon("go-previous"), i18nc("@action go to the main screen", "Back"), this);
-    actionCollection()->addAction("Back", m_BackAction);
-    connect(m_BackAction, SIGNAL(triggered(bool)), SLOT(GoBack()));
+    m_BackAction  = new QWidgetAction(this);
+    m_BackAction->setText(i18nc("@action go to the main screen", "Back"));
+    m_BackAction->setIcon(QIcon::fromTheme(QStringLiteral("go-previous")));
+    actionCollection()->addAction(QStringLiteral("Back"), m_BackAction);
+    actionCollection()->setDefaultShortcuts(m_BackAction, KStandardShortcut::shortcut(KStandardShortcut::Back));
+    connect(m_BackAction, &QAction::triggered, this, &FractionRingWidget::GoBack);
 
     // hint action (hide it as it doesn't exist here)
-    m_HintAction  = new KAction(KIcon("games-hint"), i18nc("@action opens hint", "Hint"), this);
-    actionCollection()->addAction("Hint", m_HintAction);
-    connect(m_HintAction, SIGNAL(triggered(bool)), SLOT(Hint()));
+    m_HintAction  = new QAction(QIcon::fromTheme(QStringLiteral("games-hint")), i18nc("@action opens hint", "Hint"), this);
+    actionCollection()->addAction(QStringLiteral("Hint"), m_HintAction);
+    connect(m_HintAction, &QAction::triggered, this, &FractionRingWidget::Hint);
 
     // quit action
-    KStandardAction::quit(kapp, SLOT(quit()), actionCollection());
+    KStandardAction::quit(this, SLOT(close()), actionCollection());
 
     KStandardAction::preferences(this,  SLOT(slotPrefs()), actionCollection());
 
-    if (!initialGeometrySet())
-        resize(QSize(725, 330).expandedTo(minimumSizeHint()));
+    resize(QSize(725, 330).expandedTo(minimumSizeHint()));
     setupGUI(ToolBar | Keys | StatusBar | Create);
     setAutoSaveSettings();
 }
@@ -225,22 +228,21 @@ void FractionRingWidget::setupActions()
 void FractionRingWidget::slotPrefs()
 {
 #ifdef DEBUG
-    kDebug() << "slotPrefs FractionRingWidget";
+    qDebug() << QStringLiteral("slotPrefs FractionRingWidget");
 #endif
     // do not show dialog twice
-    if (KConfigDialog::showDialog("settings"))
+    if (KConfigDialog::showDialog(QStringLiteral("settings")))
         return;
 
     //KConfigDialog didn't find an instance of this dialog, so lets create it :
-    KConfigDialog* configDialog = new KConfigDialog(this, "settings", SettingsClass::self());
+    KConfigDialog* configDialog = new KConfigDialog(this, QStringLiteral("settings"), SettingsClass::self());
 
     TaskColors * taskColors = new TaskColors(0);
-    configDialog->addPage(taskColors, i18n("Colors"), "preferences-desktop-color");
+    configDialog->addPage(taskColors, i18n("Colors"), QStringLiteral("preferences-desktop-color"));
 
     // User edited the configuration - update your local copies of the
     // configuration data
-    connect(configDialog, SIGNAL(settingsChanged(QString)), this, SLOT(slotApplySettings()));
-    configDialog->setHelp("kbruch/index.html");
+    connect(configDialog, &KConfigDialog::settingsChanged, this, &FractionRingWidget::slotApplySettings);
     configDialog->show();
 
     return;
@@ -249,7 +251,7 @@ void FractionRingWidget::slotPrefs()
 void FractionRingWidget::slotApplySettings()
 {
 #ifdef DEBUG
-    kDebug() << "slotApplySettings FractionRingWidget";
+    qDebug() << QStringLiteral("slotApplySettings FractionRingWidget");
 #endif
     fractionWidget->update();
     return;
@@ -361,7 +363,7 @@ void FractionRingWidget::slotLeftSpinBoxValueChanged(int value)
                    "This is called finding the main denominator. "
                    "The main denominator divides the rings into equal parts.");
         if (rLeft.denominator() * value != MCM(rLeft.denominator(), rRight.denominator())) {
-            msg += QString("\n\n");
+            msg += QStringLiteral("\n\n");
             msg += i18n("There is a smaller main denominator. Can you find it?");
         }
 
@@ -375,7 +377,7 @@ void FractionRingWidget::slotLeftSpinBoxValueChanged(int value)
     }
 
     update();
-    fractionWidget->paintFraction("+", rLeft, multLeft, rRight, multRight);
+    fractionWidget->paintFraction(QStringLiteral("+"), rLeft, multLeft, rRight, multRight);
 }
 
 void FractionRingWidget::slotRightSpinBoxValueChanged(int value)
@@ -389,7 +391,7 @@ void FractionRingWidget::slotRightSpinBoxValueChanged(int value)
                    "This is called finding the main denominator. "
                    "The main denominator divides the rings into equal parts.");
         if (rRight.denominator() * value != MCM(rLeft.denominator(), rRight.denominator())) {
-            msg += QString("\n\n");
+            msg += QStringLiteral("\n\n");
             msg += i18n("There is a smaller main denominator. Can you find it?");
         }
 
@@ -403,7 +405,7 @@ void FractionRingWidget::slotRightSpinBoxValueChanged(int value)
     }
 
     update();
-    fractionWidget->paintFraction("+", rLeft, multLeft, rRight, multRight);
+    fractionWidget->paintFraction(QStringLiteral("+"), rLeft, multLeft, rRight, multRight);
 }
 
 void FractionRingWidget::NewTask()
@@ -448,7 +450,7 @@ void FractionRingWidget::resetFraction(bool flag = true)
 
     if (flag) {
         update();
-        fractionWidget->paintFraction("+", rLeft, multLeft, rRight, multRight);
+        fractionWidget->paintFraction(QStringLiteral("+"), rLeft, multLeft, rRight, multRight);
     }
 }
 
